# jaxlem

jaxlem is a Python implementation of Reinforcement Learning agents built upon JAX. The PyPI page of the project can be found [here](https://pypi.org/project/jaxlem/).

## Installation
You can install the latest version of jaxagents from PyPI via:

```sh
pip install jaxlem
```

## Content

So far, the project includes the following features:
* Slope stability analysis with undrained shear strength.
* Calculation of the FoS using vmap over potential failure circles.
* Calculation of the FoS using Gradient Descent.
* Reliability analysis with Random Fields using Monte Carlo via vmap.
* Reliability analysis with Random Fields using FORM.